@@ -32,19 +32,20 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#include <stdlib.h>
+#include <stdio.h>
+#include <time.h>
+#include <string.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
-#ifndef _XOPEN_SOURCE
-#define _XOPEN_SOURCE /* glibc2 needs this */
-#endif
-#include <time.h>
 #include <libgnomevfs/gnome-vfs.h>
-#include <libxml/parser.h>
-#include <libxml/tree.h>
-#include <libxml/xpath.h>
-#include <libxml/xpathInternals.h>
-#include <string.h> 
-#ifdef HILDON 
+#include <sys/types.h>
+#include <libosso.h>
+#include <wchar.h>
+#include <limits.h>
+#include <libintl.h>
+#include <locale.h> 
+#ifdef OS2008 
     #include <hildon/hildon-banner.h>
     #include <libhildondesktop/hildon-desktop-picture.h>
     #include <libhildondesktop/hildon-desktop-home-item.h>
@@ -56,42 +57,111 @@
 #else
     #include <hildon-widgets/hildon-banner.h>
 #endif
-#include <sys/types.h>
-#include <libosso.h>
-#include <wchar.h>
-#include <stdio.h>
-#include <limits.h>
-/* localization headers and defines */
-#include <libintl.h>
-#include <locale.h>
+
 #ifdef USE_CONIC
 #include <conic/conic.h>
 #endif
+#include <libxml/parser.h>
+#include <libxml/tree.h>
+#include <libxml/xpath.h>
+#include <libxml/xpathInternals.h>
 /*******************************************************************************/
 #define _(String) dgettext (GETTEXT_PACKAGE, String)
-#define Max_count_weather_day	5
-#define COUNTRIESFILE		"/usr/share/omweather/countries.list"
-#define REGIONSFILE		"/usr/share/omweather/regions.list"
-#define LOCATIONSFILE		"/usr/share/omweather/locations.list"
+#define Max_count_weather_day	10
+#define COUNTRIESFILE		"countries.list"
+#define REGIONSFILE		"regions.list"
+#define LOCATIONSFILE		"locations.list"
 #define ICONS_PATH		"/usr/share/omweather/icons/"
-#define GIANT_ICON_SIZE		128
-#define LARGE_ICON_SIZE		96
-#define BIG_ICON_SIZE		80
-#define MEDIUM_ICON_SIZE	64
-#define SMALL_ICON_SIZE		48
-#define TINY_ICON_SIZE		32
+#define BUTTON_ICONS		"/usr/share/omweather/button_icons/"
+#define START_FUNCTION		fprintf(stderr,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);
+#define END_FUNCTION		fprintf(stderr,"\n>>>>>>>>>End %s()\n", __PRETTY_FUNCTION__);
 /*******************************************************************************/
-enum { AUTOUPDATE, DAYTIMEEVENT, DBUSINITEVENT, UPDATE_AFTER_CONNECTED, CHECK_GPS_POSITION};
+enum { AUTOUPDATE, CHANGE_DAY_PART, DBUSINITEVENT, UPDATE_AFTER_CONNECTED, CHECK_GPS_POSITION};
 enum { ONE_ROW, ONE_COLUMN, TWO_ROWS, TWO_COLUMNS, COMBINATION };
 enum { METERS, KILOMETERS, MILES, SEA_MILES };
-enum {	METERS_S,
-/*	KILOMETERS_S,
-	MILES_S,
-	METERS_H,
-*/	KILOMETERS_H,
-	MILES_H };
+enum { METERS_S, KILOMETERS_H, MILES_H };
 enum { CELSIUS, FAHRENHEIT };
-enum {  UNKNOWN, TINY, SMALL, MEDIUM, LARGE, GIANT };
+enum { INVALID_VALUE = 0, TINY, SMALL, MEDIUM, LARGE, GIANT };
+enum { ICON, STATION_NAME };
+enum { MB, INCH };
+enum { WEATHER_COM1, WEATHER_COM2, RP5_RU, MAX_WEATHER_SOURCE_NUMBER };
+enum { TINY_ICON_SIZE = 32, SMALL_ICON_SIZE = 48, MEDIUM_ICON_SIZE = 64,
+	BIG_ICON_SIZE = 80, LARGE_ICON_SIZE = 96, GIANT_ICON_SIZE = 128,
+	SUPER_GIANT_ICON_SIZE = 256 };
+enum { SETTINGS_STATIONS_PAGE, SETTINGS_VISUALS_PAGE, SETTINGS_DISPLAY_PAGE,
+	SETTINGS_UNITS_PAGE, SETTINGS_UPDATE_PAGE, SETTINGS_SENSOR_PAGE, ABOUT_PAGE };
+/* station tab */
+enum { STATE_ENABLE_GPS	= 1U,
+       STATE_SOURCE	= 2U
+};
+/* visuals tab */
+enum { STATE_ONE_ROW		= 1U,
+       STATE_ONE_COLUMN		= 2U,
+       STATE_TWO_ROWS		= 4U,
+       STATE_TWO_COLUMNS	= 8U,
+       STATE_COMBINATION	= 16U,
+       STATE_THEME_OVERRIDE	= 32U,
+       STATE_TRANSPARENCY	= 64U,
+       STATE_FONT		= 128U,
+       STATE_FONT_COLOR		= 256U,
+       STATE_BACKGROUND_COLOR	= 512U,
+       STATE_ICONSET		= 1024U
+};
+/* display tab */
+enum { STATE_VISIBLE_ITEMS	= 1U,
+       STATE_ICON_SIZE		= 2U,
+       STATE_SHOW_CURRENT	= 4U,
+       STATE_SWAP_TEMPERATURE	= 8U,
+       STATE_SHOW_WIND		= 16U,
+       STATE_SHOW_STATION_NAME	= 32U,
+       STATE_SHOW_ARROWS	= 64U
+};
+/* units tab */
+enum { STATE_CELCIUS		= 1U,
+       STATE_FAHRENHEIT		= 2U,
+       STATE_METERS		= 4U,
+       STATE_KILOMETERS		= 8U,
+       STATE_MILES		= 16U,
+       STATE_SEA_MILES		= 32U,
+       STATE_METERS_S		= 64U,
+       STATE_KILOMETERS_H	= 128U,
+       STATE_MILES_H		= 256U,
+       STATE_PRESSURE_MB	= 512U,
+       STATE_PRESSURE_IN	= 1024U
+};
+/* update tab */
+enum { STATE_AUTO_CONNECT	= 1U,
+       STATE_SWITCH_TO_NEXT	= 2U,
+       STATE_VALID_TIME		= 4U,
+       STATE_UPDATING_TIME	= 8U
+};
+/* sensor tab */
+enum { STATE_USE_SENSOR		= 1U,
+       STATE_SHOW_AT_NAME	= 2U,
+       STATE_SHOW_AT_ICON	= 4U,
+       STATE_SENSOR_READ_TIME	= 8U
+};
+/*******************************************************************************/
+typedef struct{
+    gint	error;
+    xmlDoc	*doc;
+    xmlNode	*weather_com_root;
+}weather_com_parser;
+/*******************************************************************************/
+typedef struct{
+    GSList	*location;
+    GSList	*current;
+    GSList	*days;
+    gboolean	current_data_is_invalid;
+}WeatherStationData;
+/*******************************************************************************/
+typedef struct weather_data_source{
+    gchar	*name;
+    gchar	*db_path;
+    gchar	*url;
+    gint 	(*parser)(const gchar *station_id, weather_com_parser *parser,
+			    WeatherStationData *wsd);
+}WeatherSource;
 /*******************************************************************************/
 typedef struct weather_day_button_with_image{
     GtkWidget	*button;                                                                                               
@@ -101,37 +171,6 @@ typedef struct weather_day_button_with_image{
     GtkWidget   *icon_image; 
 }WDB;
 /*******************************************************************************/
-typedef struct{
-    int		icon;
-    gchar	title[80];		/* Title */
-    gchar	hmid[80];       	/* Humidity */
-    gchar	wind_speed[80];       	/* Wind Speed */
-    gchar	wind_gust[80];        	/* Wind Gust */
-    gchar	vis[80];              	/* Visibilty */
-    gchar	wind_title[80];		/* Wind Title */
-    gchar	temp[20];		/* Temperature */
-    time_t	begin_time;		/* Begin time party of the day */
-    float	pressure;		/* Pressure value */
-    gchar	pressure_str[80];	/* Pressure direction */
-    int		moon_icon;		/* moon icon */
-    gchar	moon[60];		/* moon phase */
-}part_of_day;
-/*******************************************************************************/
-typedef struct{
-    part_of_day	day;		/* Or current weather */
-    part_of_day	night;
-    gchar	date[40];	/* Date */     
-    time_t	date_time;	/* Date of the year or current time*/  
-    time_t      zone;           /* time zone */
-    gchar	sunrise[60];	/* sunrise */
-    gchar	sunset[60];	/* sunset */
-    gchar	dayshname[60];	/* Short name of day */
-    gchar	dayfuname[60];	/* Full name of day */
-    gchar	hi_temp[20];	/* High temperature of day or real current temperature for current day */
-    gchar	low_temp[20];	/* Low temperature  of day or feels like temperature for current day */
-    gchar	location[50];	/* Location */
-}weather_day;
-/*******************************************************************************/
 struct event_time{
     time_t	time;          	/* Time event */
     short	type_event; 	/* Type of event: Automatic update event AUTOUPDATE, 
@@ -143,12 +182,6 @@ struct time_update{
     gchar	*name_between_time;  /* Human string it time */
 };
 /*******************************************************************************/
-struct weather_station{
-    gchar	*id_station;
-    gchar	*name_station;
-    gboolean    is_gps;
-};
-/*******************************************************************************/
 typedef	struct{
     char	name[50];
     long	start;
@@ -175,11 +208,14 @@ typedef struct{
 typedef struct applet_config{
     gchar	*cache_dir_name;
     gchar	*icon_set;
+    gchar	*font;
     gchar	*current_country;
     gchar	*current_station_name;
     gchar	*current_station_id;
+    guint	current_station_source;
     gchar 	*iap_http_proxy_host;
     gchar 	*cache_directory;
+    gint	weather_source;
     gint 	iap_http_proxy_port;
     gint	update_interval;
     gint	switch_time;
@@ -191,16 +227,27 @@ typedef struct applet_config{
     gint	distance_units;
     gint	wind_units;
     gint	temperature_units;
+    gint	pressure_units;
+#if defined(OS2008) || defined(DEBUGTEMP)
+    gint	display_at;
+    gboolean	use_sensor;
+    guint	sensor_update_time;
+    guint 	alpha_comp;
+    guint	corner_radius;
+#endif
     guint	data_valid_interval;
     gboolean	transparency;
     gboolean	separate;
     gboolean	swap_hi_low_temperature;
-    gboolean	hide_station_name;
-    gboolean	hide_arrows;
+    gboolean	show_station_name;
+    gboolean	show_arrows;
     gboolean	downloading_after_connecting;
     gboolean    gps_station;
+    gboolean	show_wind;
     GdkColor	font_color;
     GdkColor	background_color;
+    GdkColor	ui_background_color;
+    gboolean	ui_background_color_on;
 }AppletConfig;
 /*******************************************************************************/
 typedef struct OMWeatherApplet{
@@ -210,21 +257,33 @@ typedef struct OMWeatherApplet{
     GtkWidget		*main_window;
     GtkWidget		*popup_window;
     GtkWidget		*popup_window_more;    
-    int			button_pressed;
+    gint		button_pressed;
     AppletConfig	*config;
     gboolean		show_update_window;
     gboolean		iap_connected;
     gboolean		iap_connecting;
-    long		iap_connecting_timer;  
+    glong		iap_connecting_timer;  
     guint		timer;
     guint		timer_for_os2008;
     guint		switch_timer;
-    WDB			*buttons[Max_count_weather_day];
+    guint		sensor_timer;
+    guint		count_day;		/* days number from parser */
+    guint		stations_tab_start_state;
+    guint		stations_tab_current_state;
+    guint		visuals_tab_start_state;
+    guint		visuals_tab_current_state;
+    guint		display_tab_start_state;
+    guint		display_tab_current_state;
+    guint		units_tab_start_state;
+    guint		units_tab_current_state;
+    guint		update_tab_start_state;
+    guint		update_tab_current_state;
+    guint		sensor_tab_start_state;
+    guint		sensor_tab_current_state;
+    GSList		*buttons;
     guint		flag_updating;
     gboolean		dbus_is_initialize;
     gboolean		gps_must_be_current;    
-    weather_day		weather_current_day;
-    weather_day		weather_days[Max_count_weather_day];
     GtkListStore	*countrys_list;
     GtkListStore	*regions_list;
     GtkListStore	*stations_list;
@@ -232,7 +291,7 @@ typedef struct OMWeatherApplet{
     GtkListStore	*time_update_list;
     GtkWidget 		*contextmenu;
     gboolean 		widget_first_start;
-    int 		widget_showing;
+    gint 		widget_showing;
     gboolean 		home_item_flag_expose;
     gboolean 		area_button_pressed;
     gboolean 		area_button_release;
@@ -249,31 +308,69 @@ typedef struct OMWeatherApplet{
     GtkWidget 		*parent_parent;
     GtkWidget 		*parent;
     gpointer		*child_data;
-    int 		ax;
-    int			ay;
-    int			aw;
-    int			ah;
-#ifdef HILDON
+    gint 		ax;
+    gint		ay;
+    gint		aw;
+    gint		ah;
+#ifdef OS2008
     guint		gps_id_connection;
     LocationGPSDevice 	*gps_device;
     Station		gps_station;
     gdouble		temporary_station_latitude;
     gdouble		temporary_station_longtitude;
-#endif    
-    gchar               temperature_string[1024];
-    gchar               forecast_string[2048];
+#endif
+#if defined(OS2008) || defined(DEBUGTEMP)
+    gfloat		sensor_data;
+#endif
 #ifdef USE_CONIC    
     ConIcConnection 	*connection;
-#endif    
+#endif
+    WeatherStationData	wsd;
 }OMWeatherApp;
-
 /*******************************************************************************/
-void free_list_time_event(void);
-void time_event_add(time_t time_value, short int type_event);
-void weather_frame_update(gboolean check);
-extern void popup_window_destroy(void);
-extern int new_read_config(AppletConfig*);
+extern	OMWeatherApp	*app;
 /*******************************************************************************/
-extern OMWeatherApp	*app;
-/*******************************************************************************/
+#ifdef OS2008 
+G_BEGIN_DECLS
+
+#define TYPE_OMWEATHER (omweather_get_type())
+#define OMWEATHER(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), \
+			TYPE_OMWEATHER, OMWeather))
+#define OMWEATHER_CLASS(klass) \
+		(G_TYPE_CHECK_CLASS_CAST((klass), TYPE_OMWEATHER, OMWeather))
+#define IS_OMWEATHERT(obj)	(G_TYPE_CHECK_INSTANCE_TYPE((obj), \
+			TYPE_OMWEATHER))
+#define IS_OMWEATHERT_CLASS(klass) \
+		(G_TYPE_CHECK_CLASS_TYPE((klass), TYPE_OMWEATHER))
+#define IS_OMWEATHER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), \
+			TYPE_OMWEATHER, OMWeather))
+#define OMWEATHER_GET_PRIVATE(obj) \
+		(G_TYPE_INSTANCE_GET_PRIVATE((obj), TYPE_OMWEATHER, \
+				OMWeather))
+
+
+typedef struct _OMWeatherPrivate OMWeatherPrivate;
+
+/* Instance struct */
+typedef struct {
+	HildonDesktopHomeItem parent;
+	GtkWidget			   *layout;
+	GnomeVFSMonitorHandle  *fileMon;
+	guint                  updateTimeout;
+	gboolean			   queueRefresh;
+	XRectangle			   clip;
+	OMWeatherPrivate *priv;
+} OMWeather;
+
+/* Class struct */
+typedef struct {
+	HildonDesktopHomeItemClass parent_class;
+} OMWeatherClass;
+
+
+GType omweather_get_type(void);
+
+
+G_END_DECLS
+#endif
 #endif
