@@ -29,16 +29,23 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
+#ifdef RELEASE
+#undef DEBUGFUNCTIONCALL
+#endif
 /*******************************************************************************/
-#define CLOCK_FILE		"/usr/share/omweather/city_in_clock.txt"
+#define CLOCK_FILE	"/usr/share/omweather/city_in_clock.txt"
+#define	DEFAULT_FONT	"Sans 12"
 /*******************************************************************************/
 /* Change the weather cache directory and update dependent variables. */
-gboolean config_set_weather_dir_name(gchar *new_weather_dir_name){
+gboolean
+config_set_weather_dir_name(gchar *new_weather_dir_name){
     GnomeVFSURI *weather_dir_uri;
     gboolean retval = FALSE;
     GnomeVFSURI *parent, *curr_uri;
     GList *list = NULL;
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     /* Rest of the function devoted to making sure the directory exists. */
     weather_dir_uri = gnome_vfs_uri_new(new_weather_dir_name);
     if(!gnome_vfs_uri_exists(weather_dir_uri)){
@@ -66,7 +73,8 @@ gboolean config_set_weather_dir_name(gchar *new_weather_dir_name){
     return retval;
 }
 /*******************************************************************************/
-void fill_user_stations_list_from_clock(GtkListStore** list){
+void
+fill_user_stations_list_from_clock(GtkListStore** list){
     FILE	*clock_file;  
     gchar	*home_city = NULL,
 		*remote_city = NULL,
@@ -75,31 +83,25 @@ void fill_user_stations_list_from_clock(GtkListStore** list){
 		*station_code = NULL,
 		buffer[1024];
     GtkTreeIter	iter;
-
-
-#ifndef RELEASE
-    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
-#endif
-        
     GConfClient *gconf_client = gconf_client_get_default();
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif        
     /* City name from config file of clock */
     home_city = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_CLOCK_HOME_LOCATION, NULL);
-
     if(!home_city)
 	return;
     remote_city = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_CLOCK_REMOTE_LOCATION, NULL);
-				    
     if(!remote_city)
 	return;
-
     /* This is code for the first start during installation of deb packet */
     if ((clock_file = fopen(CLOCK_FILE, "r")) == NULL)
 	sleep (25);
     else
 	fclose(clock_file);
-
+	
     if((clock_file = fopen(CLOCK_FILE, "r"))){
 	while(!feof(clock_file)){
 	    memset(buffer, 0, sizeof(buffer));
@@ -121,11 +123,13 @@ void fill_user_stations_list_from_clock(GtkListStore** list){
                 gtk_list_store_set(*list, &iter,
                                     0, station_name,
                                     1, station_code,
+				    2, 0,
                                     -1);
 		/* A current station */
 		if(!strncmp(buffer, home_city, tmp - buffer)){
 		    app->config->current_station_id = station_code;
 		    app->config->current_station_name = station_name;
+		    app->config->current_station_source = 0;
 		}
 	    }	    
 	}
@@ -137,16 +141,21 @@ void fill_user_stations_list_from_clock(GtkListStore** list){
 	g_free(remote_city);	
 }
 /*******************************************************************************/
-void fill_user_stations_list(GSList *source_list, GtkListStore** list){
+void
+fill_user_stations_list(GSList *source_list, GtkListStore** list){
     GtkTreeIter iter;
     gchar	*temp1 = NULL,
 		*temp2 = NULL,
+		*temp3 = NULL,
 		*station_name = NULL,
 		*station_code = NULL;
-#ifdef HILDON
+    guint	station_source = 0;
+#ifdef OS2008
     gboolean	is_gps = FALSE;
 #endif
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     while(source_list){
 	temp1 = strdup((gchar*)source_list->data);
    /* Delimit Id and name */
@@ -160,27 +169,36 @@ void fill_user_stations_list(GSList *source_list, GtkListStore** list){
 	    temp2 = strtok(NULL,"@"); /* Delimiter - @ */ 
 	    if(temp2)
 		station_name = g_strdup(temp2);
-#ifdef HILDON		
-	    if  (app->gps_station.id0 && app->gps_station.name &&
-                station_code && station_name &&
-                !strcmp(app->gps_station.id0, station_code) &&
-		!strcmp(app->gps_station.name, station_name))
+	    /* station source */
+	    temp3 = strtok(NULL, "@");
+	    if(temp3)
+		station_source = (guint)atoi(temp3);
+	    
+#ifdef OS2008		
+	    if(app->gps_station.id0 && app->gps_station.name &&
+            	    station_code && station_name &&
+            	    !strcmp(app->gps_station.id0, station_code) &&
+		    !strcmp(app->gps_station.name, station_name))
 		is_gps = TRUE;
 	    else
 		is_gps = FALSE;
 #endif		
-	    /* Add station to stations list */
-            gtk_list_store_append(*list, &iter);
-            gtk_list_store_set(*list, &iter,
-#ifdef HILDON
-                                0, station_name,
-                                1, station_code,
-				2, is_gps,
+	    if(station_name && station_code){
+		/* Add station to stations list */
+        	gtk_list_store_append(*list, &iter);
+        	gtk_list_store_set(*list, &iter,
+#ifdef OS2008
+                            	    0, station_name,
+                            	    1, station_code,
+				    2, is_gps,
+				    3, station_source,
 #else
-                                0, station_name,
-                                1, station_code,
+                            	    0, station_name,
+                            	    1, station_code,
+				    3, station_source,
 #endif
-                                -1);
+                            	    -1);
+            }
 	    station_name && (g_free(station_name) , station_name = NULL);
 	    station_code && (g_free(station_code) , station_code = NULL);
 	}
@@ -189,14 +207,18 @@ void fill_user_stations_list(GSList *source_list, GtkListStore** list){
     }
 }
 /*******************************************************************************/
-GSList* create_stations_string_list(void){
+GSList*
+create_stations_string_list(void){
     GSList      *stlist = NULL;
     GtkTreeIter	iter;
     gboolean	valid;
     gchar	*station_name = NULL,
 		*station_code = NULL,
 		*str = NULL;
-    
+    guint	station_source = 0;
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif    
     valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
 					    &iter);
     while(valid){
@@ -204,9 +226,10 @@ GSList* create_stations_string_list(void){
 			    &iter, 
                     	    0, &station_name,
                     	    1, &station_code,
+			    3, &station_source,
                     	    -1);
-	str = g_strdup_printf("%s@%s", station_code,
-					    station_name);
+	str = g_strdup_printf("%s@%s@%d", station_code, station_name,
+				station_source);
 	stlist = g_slist_append(stlist, str);
 	g_free(station_name);
 	g_free(station_code);
@@ -216,10 +239,13 @@ GSList* create_stations_string_list(void){
     return stlist;
 }
 /*******************************************************************************/
-GtkListStore* create_time_update_list(void){
+GtkListStore*
+create_time_update_list(void){
     GtkListStore	*list = NULL;
     GtkTreeIter         iter;
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     list = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
     
     gtk_list_store_append(list, &iter);
@@ -244,7 +270,8 @@ GtkListStore* create_time_update_list(void){
     return list;
 }
 /*******************************************************************************/
-int new_read_config(AppletConfig *config){
+gint
+read_config(AppletConfig *config){
     GConfValue	*value = NULL;
     GConfClient *gconf_client = NULL;
     int		fd = -1;
@@ -254,10 +281,9 @@ int new_read_config(AppletConfig *config){
     gchar	tmp_buff[1024],
 		*home_dir,
 		*tmp = NULL;
-#ifndef RELEASE
-    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
 #endif
-
     gconf_client = gconf_client_get_default();
 
     if(!gconf_client){
@@ -298,13 +324,13 @@ int new_read_config(AppletConfig *config){
     if (config->current_station_id && strlen(config->current_station_id) == 0)
 	config->current_station_id = NULL;
     /* Get GPS station name and id */
-#ifdef HILDON
+#ifdef OS2008
     app->gps_station.name[0] = 0;
     tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_GPS_STATION_NAME, NULL);
     if(tmp){
-	snprintf(app->gps_station.name,sizeof(app->gps_station.name)-1,"%s",tmp);
+	snprintf(app->gps_station.name, sizeof(app->gps_station.name) - 1, "%s", tmp);
     	g_free(tmp);
     }	
     app->gps_station.id0[0] = 0;
@@ -312,12 +338,11 @@ int new_read_config(AppletConfig *config){
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_GPS_STATION_ID, NULL);
     if(tmp){
-    	snprintf(app->gps_station.id0,sizeof(app->gps_station.id0)-1,"%s",tmp);
+    	snprintf(app->gps_station.id0, sizeof(app->gps_station.id0) - 1, "%s", tmp);
 	g_free(tmp);
 	tmp = NULL;
     }
 #endif    
-    
     /* Get Weather Stations ID and NAME */
     stlist = gconf_client_get_list(gconf_client,
         			    GCONF_KEY_WEATHER_STATIONS_LIST,
@@ -338,13 +363,20 @@ int new_read_config(AppletConfig *config){
     }
     else
 	close(fd);
-    /* Get Weather Icon Size  */		     
+    /* Get weather data source */ 
+    config->weather_source = gconf_client_get_int(gconf_client,
+					    GCONF_KEY_WEATHER_DATA_SOURCE,
+					    NULL);
+    if(config->weather_source < WEATHER_COM1 &&
+	    config->weather_source > RP5_RU)
+	config->weather_source = WEATHER_COM2;
+
+    /* Get Weather Icon Size  */
     config->icons_size = gconf_client_get_int(gconf_client,
         				    GCONF_KEY_WEATHER_ICONS_SIZE,
 					    NULL);
     if(config->icons_size < TINY || config->icons_size > GIANT)
         config->icons_size = LARGE;    
-
     /* Get setting tab number  */		     
     config->current_settings_page = gconf_client_get_int(gconf_client,
         				    GCONF_KEY_WEATHER_SETTING_TAB_NUMBER,
@@ -353,6 +385,7 @@ int new_read_config(AppletConfig *config){
 	config->current_settings_page > MAX_SETTINGS_PAGE_NUMBER)
         config->current_settings_page = 0;
 
+
     /* Get Weather country name. */    
     config->current_country = gconf_client_get_string(gconf_client,
         					    GCONF_KEY_WEATHER_CURRENT_COUNTRY_NAME,
@@ -373,7 +406,7 @@ int new_read_config(AppletConfig *config){
     remove_periodic_event();		/* delete event from list */
     add_periodic_event(time(NULL));	/* add new event */
     
-#ifdef HILDON
+#ifdef OS2008
     /* Get gps_station. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_USE_GPS_STATION, NULL);
     if(value){
@@ -392,8 +425,24 @@ int new_read_config(AppletConfig *config){
     if(!tmp || !gdk_color_parse(tmp, &(config->font_color)))
          config->font_color = DEFAULT_FONT_COLOR; 
     g_free(tmp);
-    
-    /* Get background color. */    	
+
+    /* Get font description. */
+    tmp = NULL;
+    tmp = gconf_client_get_string(gconf_client,
+        			    GCONF_KEY_WEATHER_FONT, NULL);
+    if(!tmp)
+        config->font = g_strdup(DEFAULT_FONT);
+    else{
+	config->font = g_strdup(tmp);
+	g_free(tmp);
+    }
+
+    /* Get UI background color */
+    config->ui_background_color_on = TRUE;
+    config->ui_background_color.red = 0xCCCC;
+    config->ui_background_color.blue = 0xCCCC;
+    config->ui_background_color.green = 0xCCCC;
+    /* Get background color. */
     tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_BACKGROUND_COLOR, NULL);
@@ -401,15 +450,16 @@ int new_read_config(AppletConfig *config){
          config->background_color = DEFAULT_FONT_COLOR; 
     g_free(tmp);
     tmp = NULL;
-
-    /* Get Enable Transparency flag. Default is TRUE. */
-    value = gconf_client_get(gconf_client, GCONF_KEY_ENABLE_TRANSPARENCY, NULL);
-    if(value){
-        config->transparency = gconf_value_get_bool(value);
-        gconf_value_free(value);
-    }
-    else
-        config->transparency = TRUE;
+    #ifndef OS2008
+	/* Get Enable Transparency flag. Default is TRUE. */
+	value = gconf_client_get(gconf_client, GCONF_KEY_ENABLE_TRANSPARENCY, NULL);
+	if(value){
+    	    config->transparency = gconf_value_get_bool(value);
+    	    gconf_value_free(value);
+	}
+	else
+    	    config->transparency = TRUE;
+    #endif    
     /* Get Split Button State. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_SEPARATE_DATA, NULL);
     if(value){
@@ -418,7 +468,53 @@ int new_read_config(AppletConfig *config){
     }
     else
         config->separate = FALSE;
-
+#ifdef OS2008
+    /* Get Use sensor Button State. Default is FALSE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_USE_SENSOR, NULL);
+    if(value){
+        config->use_sensor = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    }
+    else
+        config->use_sensor = FALSE;
+    /* Get display sensor at  */
+    config->display_at = gconf_client_get_int(gconf_client,
+        				    GCONF_KEY_DISPLAY_SENSOR_AT,
+					    NULL);
+    if(config->display_at < ICON || config->display_at > STATION_NAME)
+        config->display_at = STATION_NAME;
+    /* Get sensor update time  */
+    config->sensor_update_time = gconf_client_get_int(gconf_client,
+        				    GCONF_KEY_SENSOR_UPDATE_TIME,
+					    NULL);
+    if(config->sensor_update_time < 0 || config->sensor_update_time > 30)
+        config->sensor_update_time = 0;
+    /* start timer for read data from device temperature sensor */
+    if(config->use_sensor){
+	read_sensor(0);
+	app->sensor_timer = g_timeout_add(config->sensor_update_time * 1000 * 60,
+                                            (GtkFunction)read_sensor,
+                                            GINT_TO_POINTER(1));
+    }
+    /* Get value of transparence default 0 */
+    config->alpha_comp = gconf_client_get_int(gconf_client,
+                			    GCONF_KEY_ALPHA_COMPONENT,
+					    &gerror);
+    if(gerror || config->alpha_comp <= 0){
+	config->alpha_comp = 0;
+	if(gerror)
+	    g_error_free(gerror);
+    }
+	/* Get value of corner radius. Default is 10 */
+	config->corner_radius = gconf_client_get_int(gconf_client,
+							GCONF_KEY_CORNER_RADIUS,
+							&gerror);
+	if(gerror || config->corner_radius <= 0){
+	    config->corner_radius = 10;
+	    if(gerror)
+		g_error_free(gerror);
+	}
+#endif
     /* Get auto_downloading_after_connecting. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_DOWNLOADING_AFTER_CONNECTING, NULL);
     if(value){
@@ -427,7 +523,7 @@ int new_read_config(AppletConfig *config){
     }
     else
         config->downloading_after_connecting = FALSE;
-	
+
     /* Get Swap Temperature Button State. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_SWAP_TEMPERATURE, NULL);
     if(value){
@@ -437,22 +533,31 @@ int new_read_config(AppletConfig *config){
     else
         config->swap_hi_low_temperature = FALSE;
 
-    /* Get Hide Station State. Default is FALSE */
-    value = gconf_client_get(gconf_client, GCONF_KEY_HIDE_STATION_NAME, NULL);
+    /* Get Show wind Button State. Default is FALSE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_SHOW_WIND, NULL);
     if(value){
-        config->hide_station_name = gconf_value_get_bool(value);
+        config->show_wind = gconf_value_get_bool(value);
         gconf_value_free(value);
     }
     else
-        config->hide_station_name = FALSE;
-    /* Get Hide Arrows State. Default is FALSE */
-    value = gconf_client_get(gconf_client, GCONF_KEY_HIDE_ARROWS, NULL);
+        config->show_wind = FALSE;
+
+    /* Get Show Station Name. Default is TRUE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_SHOW_STATION_NAME, NULL);
     if(value){
-        config->hide_arrows = gconf_value_get_bool(value);
+        config->show_station_name = gconf_value_get_bool(value);
         gconf_value_free(value);
     }
     else
-        config->hide_arrows = FALSE;
+        config->show_station_name = TRUE;
+    /* Get Show Arrows State. Default is TRUE */
+    value = gconf_client_get(gconf_client, GCONF_KEY_SHOW_ARROWS, NULL);
+    if(value){
+        config->show_arrows = gconf_value_get_bool(value);
+        gconf_value_free(value);
+    }
+    else
+        config->show_arrows = TRUE;
 
     /* Get Temperature Unit  Default Celsius */
     config->temperature_units = gconf_client_get_int(gconf_client,
@@ -468,8 +573,8 @@ int new_read_config(AppletConfig *config){
     config->icons_layout = gconf_client_get_int(gconf_client,
                 				GCONF_KEY_ICONS_LAYOUT,
 						NULL);
-    if (config->icons_layout < ONE_ROW ||
-	config->icons_layout > COMBINATION)
+    if(config->icons_layout < ONE_ROW ||
+	    config->icons_layout > COMBINATION)
 	config->icons_layout = ONE_ROW;
 
     /* Get number days to show default 5 */
@@ -493,15 +598,21 @@ int new_read_config(AppletConfig *config){
 	if(gerror)
 	    g_error_free(gerror);
     }
-
+    /* Get pressure units */
+    config->pressure_units = gconf_client_get_int(gconf_client,                                                                                     
+                				    GCONF_KEY_WEATHER_PRESSURE_UNITS,
+						    &gerror);
+    if(gerror || config->pressure_units > INCH){
+	config->pressure_units = MB;
+	g_error_free(gerror);
+    }
     /* Get wind units */
     config->wind_units = gconf_client_get_int(gconf_client,                                                                                     
 						GCONF_KEY_WEATHER_WIND_UNITS,
 						&gerror);
     if(gerror || config->wind_units > MILES_H){
 	config->wind_units = METERS_S;
-	if(gerror)
-	    g_error_free(gerror);
+	g_error_free(gerror);
     }
     /* Get switch time */
     config->switch_time = gconf_client_get_int(gconf_client,
@@ -515,7 +626,7 @@ int new_read_config(AppletConfig *config){
 		    config->switch_time != 50 &&
 		    config->switch_time != 60) ){
 	config->switch_time = 0;	/* Default value - Never */
-	if (gerror)
+	if(gerror)
 	    g_error_free(gerror);
     }
     else{
@@ -526,7 +637,6 @@ int new_read_config(AppletConfig *config){
                         	app->main_window);
 	}
     }
-    
     /* Get valid data time for current weather */
     config->data_valid_interval =
 	    gconf_client_get_int(gconf_client,
@@ -537,7 +647,7 @@ int new_read_config(AppletConfig *config){
 		    config->data_valid_interval != 4 &&
 		    config->data_valid_interval != 8) ){
 	config->data_valid_interval = 2 * 3600; /* Default value - 2 hours */
-	if (gerror)
+	if(gerror)
 	    g_error_free(gerror);
     }
     else
@@ -546,43 +656,15 @@ int new_read_config(AppletConfig *config){
     /* If this first start then fill default station from clock config */ 
     tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
-                		    GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);				    
+                		    GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);
     if(!tmp){
-	if(!app->config->current_station_id){	
+	if(!app->config->current_station_id){
 	    fill_user_stations_list_from_clock(&app->user_stations_list);
-	    if(app->iap_connected){
-		app->show_update_window = TRUE;
-		update_weather();
-	    }
+	    if(app->iap_connected)
+		update_weather(TRUE);
 	}	    
     }
     else{
-    	/* Correcting icon size for version less 0.19.5. It  must be deleted after version 0.21 */
-	if (tmp[0]=='0' && tmp[2]<'2' && tmp[3]<='9' && tmp[5]<'5'){
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 0)	
-		config->icons_size = MEDIUM;
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 1)	
-		config->icons_size = SMALL;		
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 2)	
-		config->icons_size = TINY;				
-	    if(config->icons_size < TINY || config->icons_size > GIANT)
-    		config->icons_size = LARGE;
-	}
-	/* Correcting icon size for version  0.19.5. It  must be deleted after version 0.21 */
-	if (tmp[0]=='0' && tmp[2]=='1' && tmp[3]=='9' && tmp[5]=='5'){
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 0)	
-		config->icons_size = GIANT;
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 1)	
-		config->icons_size = LARGE;		
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 2)	
-		config->icons_size = MEDIUM;			
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 3)	
-		config->icons_size = SMALL;						
-	    if (gconf_client_get_int(gconf_client,GCONF_KEY_WEATHER_ICONS_SIZE,NULL) == 4)	
-		config->icons_size = TINY;			
-	    if(config->icons_size < TINY || config->icons_size > GIANT)
-    		config->icons_size = LARGE;
-	}
 	g_free(tmp);		     
 	tmp = NULL;		
     }    
@@ -592,8 +674,12 @@ int new_read_config(AppletConfig *config){
     return 0;
 }
 /*******************************************************************************/
-void config_update_proxy(void){
+void
+config_update_proxy(void){
     GConfClient *gconf_client = gconf_client_get_default();
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(app->config->iap_http_proxy_host)
         g_free(app->config->iap_http_proxy_host);
     /* Get proxy data */
@@ -612,11 +698,14 @@ void config_update_proxy(void){
     g_object_unref(gconf_client);
 }
 /*******************************************************************************/ 
-void new_config_save(AppletConfig *config){
+void
+config_save(AppletConfig *config){
     gchar temp_buffer[16];
     GConfClient *gconf_client;
     GSList *stlist = NULL;
-   
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif   
     gconf_client = gconf_client_get_default();
     if(!gconf_client){
 	fprintf(stderr, _("Failed to initialize GConf. Settings were not saved.\n"));
@@ -664,10 +753,28 @@ void new_config_save(AppletConfig *config){
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_ICONS_SIZE,
 			config->icons_size, NULL);
+    /* Save Weather Data Source  */		     	    
+    gconf_client_set_int(gconf_client,
+        		GCONF_KEY_WEATHER_DATA_SOURCE,
+			config->weather_source, NULL);
     /* Save current setting tab number  */		     	    
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_SETTING_TAB_NUMBER,
 			config->current_settings_page, NULL);
+#ifdef OS2008
+     /* Save Use sensor Button State */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_USE_SENSOR,
+			config->use_sensor, NULL);
+    /* Save display sensor at  */		     	    
+    gconf_client_set_int(gconf_client,
+        		GCONF_KEY_DISPLAY_SENSOR_AT,
+			config->display_at, NULL);
+    /* Save sensor update time */
+    gconf_client_set_int(gconf_client,
+        		GCONF_KEY_SENSOR_UPDATE_TIME,
+			config->sensor_update_time, NULL);
+#endif
     /* Save Weather Font Color */
     sprintf(temp_buffer, "#%02x%02x%02x",
             config->font_color.red >> 8,
@@ -676,6 +783,10 @@ void new_config_save(AppletConfig *config){
     gconf_client_set_string(gconf_client,
         		    GCONF_KEY_WEATHER_FONT_COLOR,
 			    temp_buffer, NULL);
+    /* Save Font Description */
+    gconf_client_set_string(gconf_client,
+        		    GCONF_KEY_WEATHER_FONT,
+			    config->font, NULL);
     /* Save Background Color */
     sprintf(temp_buffer, "#%02x%02x%02x",
             config->background_color.red >> 8,
@@ -695,29 +806,42 @@ void new_config_save(AppletConfig *config){
      /* Save Split Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SEPARATE_DATA,
-			config->separate, NULL);	    
+			config->separate, NULL);
+
      /* Save Downloading after connecting State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_DOWNLOADING_AFTER_CONNECTING,
 			config->downloading_after_connecting, NULL);
-#ifdef HILDON
+#ifdef OS2008
      /* Save Use GPS station */
     gconf_client_set_bool(gconf_client,
         		    GCONF_KEY_USE_GPS_STATION,
 			    config->gps_station, NULL);
+    /* Save Alpha component */
+    gconf_client_set_int(gconf_client,
+        		    GCONF_KEY_ALPHA_COMPONENT,
+			    config->alpha_comp, NULL);
+	/* Save Corner Radius */
+	gconf_client_set_int(gconf_client,
+					GCONF_KEY_CORNER_RADIUS,
+				config->corner_radius, NULL);
 #endif
      /* Save Swap Temperature Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SWAP_TEMPERATURE,
 			config->swap_hi_low_temperature, NULL);	    
-     /* Hide Station Name */
+     /* Save Show Wind Button State */
     gconf_client_set_bool(gconf_client,
-        		GCONF_KEY_HIDE_STATION_NAME,
-			config->hide_station_name, NULL);
-     /* Hide Arrows */
+        		GCONF_KEY_SHOW_WIND,
+			config->show_wind, NULL);	    
+     /* Show Station Name */
     gconf_client_set_bool(gconf_client,
-        		GCONF_KEY_HIDE_ARROWS,
-			config->hide_arrows, NULL);
+        		GCONF_KEY_SHOW_STATION_NAME,
+			config->show_station_name, NULL);
+     /* Show Arrows */
+    gconf_client_set_bool(gconf_client,
+        		GCONF_KEY_SHOW_ARROWS,
+			config->show_arrows, NULL);
     /* Save Weather Temperature Unit  */		     	    
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_TEMPERATURE_UNIT,
@@ -730,6 +854,10 @@ void new_config_save(AppletConfig *config){
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_DISTANCE_UNITS,
 			config->distance_units, NULL);
+    /* Save pressure units. */
+    gconf_client_set_int(gconf_client,
+        		GCONF_KEY_WEATHER_PRESSURE_UNITS,
+			config->pressure_units, NULL);
     /* Save wind units. */
     gconf_client_set_int(gconf_client,
         		GCONF_KEY_WEATHER_WIND_UNITS,
@@ -754,14 +882,14 @@ void new_config_save(AppletConfig *config){
     /* Free stlist */	    
     g_slist_foreach(stlist, (GFunc)g_free, NULL);
     g_slist_free(stlist);
-#ifdef HILDON    
+#ifdef OS2008    
     /* Save current GPS station */
-    if (config->gps_station){
-	if (app->gps_station.name)
+    if(config->gps_station){
+	if(app->gps_station.name)
 	    gconf_client_set_string(gconf_client,
         		    GCONF_KEY_GPS_STATION_NAME,
 			    app->gps_station.name, NULL);
-	if (app->gps_station.id0)		    
+	if(app->gps_station.id0)		    
 	    gconf_client_set_string(gconf_client,
         		    GCONF_KEY_GPS_STATION_ID,
 			    app->gps_station.id0, NULL);
