@@ -29,38 +29,41 @@
 #define _weather_popup_h 1
 /*******************************************************************************/
 #include "weather-common.h"
-#include "weather-data.h"
 /*******************************************************************************/
 extern	gchar		path_large_icon[];
+extern	WeatherSource	weather_sources[];
 /*******************************************************************************/
 void popup_window_destroy(void);
-gboolean popup_window_event_cb(GtkWidget *widget, GdkEvent *event, 
-                    		    gpointer user_data);
-gboolean show_popup_window_handler(GtkWidget *widget, GdkEvent *event,
-				    gpointer user_data);
-void popup_window_more_close(GtkWidget *widget, GdkEvent *event,
-                    	    	    gpointer user_data);
-GtkWidget* create_header_widget(GSList *day);
-GtkWidget* create_temperature_range_widget(GSList *day);
-GtkWidget* create_current_weather_widget(GSList *current);
-GtkWidget* create_24_hours_widget(GSList *day);
-GtkWidget* create_footer_widget(gboolean enable_more_info);
-GtkWidget* create_footer_more_widget(void);
 GtkWidget* create_sun_time_widget(GSList *day);
 GtkWidget* create_moon_phase_widget(GSList *current);
 GtkWidget* create_time_updates_widget(GSList *current);
-float convert_wind_units(int to, float value);
-void popup_window_more_show(GtkWidget *widget, GdkEvent *event, gpointer user_data);
-void weather_window_popup_more_show(void);
-void popup_close(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+
+gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+
+void settings_button_handler(GtkWidget *button, GdkEventButton *event,
+                                                            gpointer user_data);
+void refresh_button_handler(GtkWidget *button, GdkEventButton *event,
+                                                            gpointer user_data);
+void about_button_handler(GtkWidget *button, GdkEventButton *event,
+                                                            gpointer user_data);
+void popup_close_button_handler(GtkWidget *button, GdkEventButton *event,
+                                                            gpointer user_data);
+GtkWidget* create_day_tab(GSList *current, GSList *day, gchar **day_name);
+GtkWidget* create_current_tab(GSList *current);
+GtkWidget* create_copyright_widget(const gchar *text, const gchar *image);
 /*******************************************************************************/
 extern void weather_window_settings(GtkWidget *widget, GdkEvent *event,
 				    gpointer user_data);
-extern void pre_update_weather(void);
-extern void set_font_size(GtkWidget *widget, char font_size);
+/*extern void pre_update_weather(void);*/
+extern void update_weather(gboolean show_update_window);
+extern void set_font(GtkWidget *widget, const gchar *description, const gint size);
 extern void set_font_color (GtkWidget *widget, guint16 red, guint16 green, guint16 blue);
-extern int c2f(int temp);
+extern float c2f(float temp);
 extern void swap_temperature(int *hi, int *low);
-extern gpointer hash_table_find(gpointer key);
+extern gpointer hash_table_find(gpointer key, gboolean search_short_name);
+extern float convert_wind_units(int to, float value);
+extern GtkWidget* create_button_with_image(const char *path, const char *image_name,
+			int image_size, gboolean with_border, gboolean toggled);
+extern void create_about_dialog(void);  /* create help dialog */
 /*******************************************************************************/
 #endif
